@@ -1,7 +1,7 @@
 from typing import Dict, List
 
 from .base import BaseService
-from ..common.model import Callback
+from ..model.callback import Callback
 
 
 class OssService(BaseService):
